@@ -1,3 +1,4 @@
+import inspect
 import json
 import logging as log
 from functools import wraps
@@ -366,7 +367,20 @@ class Table(metaclass=MetaTable):
         #print(params)
         # if cls.name=='user_media':print(color.magenta(cls.type.__name__))
         # if cls.name=='user_media':print(color.magenta(params))
-        return cls.type(**params)
+
+        init_args = {}
+        for argument in inspect.getargspec(cls.type).args:
+            if argument != 'self':
+                if argument in params:
+                    init_args[argument] = params[argument]
+        result = cls.type(**init_args)
+        for key, value in params.items():
+            if key not in init_args:
+                setattr(result, key, value)
+
+        return result
+
+        #return cls.type(**params)
 
 class Row:
     def __init__(self):
